@@ -28,6 +28,7 @@ if TYPE_CHECKING:
     from polars.dependencies import numpy as np
     from polars.dependencies import pandas as pd
     from polars.dependencies import pyarrow as pa
+    from polars.dependencies import torch
     from polars.lazyframe.engine_config import GPUEngine
     from polars.selectors import _selector_proxy_
 
@@ -105,6 +106,9 @@ AvroCompression: TypeAlias = Literal["uncompressed", "snappy", "deflate"]
 CsvQuoteStyle: TypeAlias = Literal["necessary", "always", "non_numeric", "never"]
 CategoricalOrdering: TypeAlias = Literal["physical", "lexical"]
 CsvEncoding: TypeAlias = Literal["utf8", "utf8-lossy"]
+DeletionFiles: TypeAlias = tuple[
+    Literal["iceberg-position-delete"], dict[int, list[str]]
+]
 FillNullStrategy: TypeAlias = Literal[
     "forward", "backward", "min", "max", "mean", "zero", "one"
 ]
@@ -127,8 +131,12 @@ ParquetCompression: TypeAlias = Literal[
 PivotAgg: TypeAlias = Literal[
     "min", "max", "first", "last", "sum", "mean", "median", "len"
 ]
+QuantileMethod: TypeAlias = Literal[
+    "nearest", "higher", "lower", "midpoint", "linear", "equiprobable"
+]
 RankMethod: TypeAlias = Literal["average", "min", "max", "dense", "ordinal", "random"]
 Roll: TypeAlias = Literal["raise", "forward", "backward"]
+RoundMode: TypeAlias = Literal["half_to_even", "half_away_from_zero"]
 SerializationFormat: TypeAlias = Literal["binary", "json"]
 Endianness: TypeAlias = Literal["little", "big"]
 SizeUnit: TypeAlias = Literal[
@@ -168,9 +176,6 @@ InterpolationMethod: TypeAlias = Literal["linear", "nearest"]
 JoinStrategy: TypeAlias = Literal[
     "inner", "left", "right", "full", "semi", "anti", "cross", "outer"
 ]  # JoinType
-RollingInterpolationMethod: TypeAlias = Literal[
-    "nearest", "higher", "lower", "midpoint", "linear"
-]  # QuantileInterpolOptions
 ListToStructWidthStrategy: TypeAlias = Literal["first_non_null", "max_width"]
 
 # The following have no equivalent on the Rust side
@@ -208,6 +213,7 @@ FrameInitTypes: TypeAlias = Union[
     "pd.DataFrame",
     "ArrowArrayExportable",
     "ArrowStreamExportable",
+    "torch.Tensor",
 ]
 
 # Excel IO
@@ -282,7 +288,6 @@ ConnectionOrCursor: TypeAlias = Union[
     BasicConnection, BasicCursor, Cursor, AlchemyConnection
 ]
 
-
 # Annotations for `__getitem__` methods
 SingleIndexSelector: TypeAlias = int
 MultiIndexSelector: TypeAlias = Union[
@@ -312,6 +317,8 @@ EngineType: TypeAlias = Union[
     Literal["auto", "in-memory", "streaming", "gpu"], "GPUEngine"
 ]
 
+PlanStage: TypeAlias = Literal["ir", "physical"]
+
 FileSource: TypeAlias = Union[
     str,
     Path,
@@ -325,6 +332,14 @@ FileSource: TypeAlias = Union[
 
 JSONEncoder = Union[Callable[[Any], bytes], Callable[[Any], str]]
 
+DeprecationType: TypeAlias = Literal[
+    "function",
+    "renamed_parameter",
+    "streaming_parameter",
+    "nonkeyword_arguments",
+    "parameter_as_multi_positional",
+]
+
 
 class PartitioningScheme:
     def __init__(
@@ -336,3 +351,118 @@ class PartitioningScheme:
     @property
     def _base_path(self) -> str | None:
         return self._py_partitioning.base_path
+
+
+__all__ = [
+    "Ambiguous",
+    "ArrowArrayExportable",
+    "ArrowStreamExportable",
+    "AsofJoinStrategy",
+    "AvroCompression",
+    "BooleanMask",
+    "BufferInfo",
+    "CategoricalOrdering",
+    "ClosedInterval",
+    "ColumnFormatDict",
+    "ColumnNameOrSelector",
+    "ColumnTotalsDefinition",
+    "ColumnWidthsDefinition",
+    "ComparisonOperator",
+    "ConcatMethod",
+    "ConditionalFormatDict",
+    "ConnectionOrCursor",
+    "CorrelationMethod",
+    "CsvEncoding",
+    "CsvQuoteStyle",
+    "Cursor",
+    "DbReadEngine",
+    "DbWriteEngine",
+    "DbWriteMode",
+    "DeprecationType",
+    "Endianness",
+    "EngineType",
+    "EpochTimeUnit",
+    "ExcelSpreadsheetEngine",
+    "ExplainFormat",
+    "FileSource",
+    "FillNullStrategy",
+    "FloatFmt",
+    "FrameInitTypes",
+    "FrameType",
+    "IndexOrder",
+    "InterpolationMethod",
+    "IntoExpr",
+    "IntoExprColumn",
+    "IpcCompression",
+    "JSONEncoder",
+    "JaxExportType",
+    "JoinStrategy",
+    "JoinValidation",
+    "Label",
+    "ListToStructWidthStrategy",
+    "MaintainOrderJoin",
+    "MapElementsStrategy",
+    "MultiColSelector",
+    "MultiIndexSelector",
+    "MultiNameSelector",
+    "NonExistent",
+    "NonNestedLiteral",
+    "NullBehavior",
+    "NumericLiteral",
+    "OneOrMoreDataTypes",
+    "Orientation",
+    "ParallelStrategy",
+    "ParametricProfileNames",
+    "ParquetCompression",
+    "PartitioningScheme",
+    "PivotAgg",
+    "PolarsDataType",
+    "PolarsIntegerType",
+    "PolarsTemporalType",
+    "PolarsType",
+    "PythonDataType",
+    "PythonLiteral",
+    "QuantileMethod",
+    "RankMethod",
+    "Roll",
+    "RowTotalsDefinition",
+    "SchemaDefinition",
+    "SchemaDict",
+    "SearchSortedSide",
+    "SelectorType",
+    "SerializationFormat",
+    "SeriesBuffers",
+    "SingleColSelector",
+    "SingleIndexSelector",
+    "SingleNameSelector",
+    "SizeUnit",
+    "StartBy",
+    "SyncOnCloseMethod",
+    "TemporalLiteral",
+    "TimeUnit",
+    "TorchExportType",
+    "TransferEncoding",
+    "UnicodeForm",
+    "UniqueKeepStrategy",
+    "UnstackDirection",
+    "WindowMappingStrategy",
+]
+
+
+class ParquetMetadataContext:
+    """
+    The context given when writing file-level parquet metadata.
+
+    .. warning::
+        This functionality is considered **experimental**. It may be removed or
+        changed at any point without it being considered a breaking change.
+    """
+
+    def __init__(self, *, arrow_schema: str) -> None:
+        self.arrow_schema = arrow_schema
+
+    arrow_schema: str  #: The base64 encoded arrow schema that is going to be written into metadata.
+
+
+ParquetMetadataFn: TypeAlias = Callable[[ParquetMetadataContext], dict[str, str]]
+ParquetMetadata: TypeAlias = Union[dict[str, str], ParquetMetadataFn]
