@@ -2,6 +2,8 @@ from __future__ import annotations
 
 import contextlib
 
+from polars._utils.various import qualified_type_name
+
 with contextlib.suppress(ImportError):  # Module not available when building docs
     import polars.polars as plr
 import polars._reexport as pl
@@ -21,7 +23,7 @@ def escape_regex(s: str) -> str:
         msg = "escape_regex function is unsupported for `Expr`, you may want use `Expr.str.escape_regex` instead"
         raise TypeError(msg)
     elif not isinstance(s, str):
-        msg = f"escape_regex function supports only `str` type, got `{type(s)}`"
+        msg = f"escape_regex function supports only `str` type, got `{qualified_type_name(s)}`"
         raise TypeError(msg)
 
     return plr.escape_regex(s)
