@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+import contextlib
 from typing import TYPE_CHECKING, Any
 
 from polars._utils.deprecation import deprecate_renamed_parameter
@@ -19,6 +20,9 @@ from polars.testing.asserts.utils import raise_assertion_error
 if TYPE_CHECKING:
     from polars import DataType
 
+with contextlib.suppress(ImportError):  # Module not available when building docs
+    from polars.polars import assert_series_equal_py
+
 
 def _assert_correct_input_type(left: Any, right: Any) -> bool:
     __tracebackhide__ = True
@@ -52,6 +56,9 @@ def assert_series_equal(
     Raises a detailed `AssertionError` if the Series differ.
     This function is intended for use in unit tests.
 
+    .. versionchanged:: 0.20.31
+        The `check_dtype` parameter was renamed `check_dtypes`.
+
     Parameters
     ----------
     left
@@ -98,25 +105,30 @@ def assert_series_equal(
     Traceback (most recent call last):
     ...
     AssertionError: Series are different (exact value mismatch)
-    [left]:  [1, 2, 3]
-    [right]: [1, 5, 3]
+    [left]: shape: (3,)
+    Series: '' [i64]
+    [
+        1
+        2
+        3
+    ]
+    [right]: shape: (3,)
+    Series: '' [i64]
+    [
+        1
+        5
+        3
+    ]
     """
     __tracebackhide__ = True
 
     _assert_correct_input_type(left, right)
 
-    if left.len() != right.len():
-        raise_assertion_error("Series", "length mismatch", left.len(), right.len())
-
-    if check_names and left.name != right.name:
-        raise_assertion_error("Series", "name mismatch", left.name, right.name)
-
-    if check_dtypes and left.dtype != right.dtype:
-        raise_assertion_error("Series", "dtype mismatch", left.dtype, right.dtype)
-
-    _assert_series_values_equal(
-        left,
-        right,
+    assert_series_equal_py(
+        left._s,
+        right._s,
+        check_dtypes=check_dtypes,
+        check_names=check_names,
         check_order=check_order,
         check_exact=check_exact,
         rtol=rtol,
@@ -379,6 +391,9 @@ def assert_series_not_equal(
 
     This function is intended for use in unit tests.
 
+    .. versionchanged:: 0.20.31
+        The `check_dtype` parameter was renamed `check_dtypes`.
+
     Parameters
     ----------
     left
